library cryfetch;

import 'package:webfeed/webfeed.dart';
import 'models/cryptocurrency.dart';
import 'interfaces/coin_provider.dart';
import 'services/database.dart';
import 'services/data_fetcher.dart';
import 'services/network_checker.dart';

class CryFetch {
  static List<Cryptocurrency> cryptoList = [];
  static List<RssFeed> feedList = [];

  final CoinProvider provider;
  final List<String> rssList;
  static bool hasNetwork = false;

  CryFetch(
      {required this.provider,
      this.rssList = const [
        "https://www.coindesk.com/arc/outboundfeeds/rss/?outputType=xml"
      ],
      hasNetwork = false}) {}
  Future<void> initialize() async {
    hasNetwork = await NetworkChecker.hasNetwork();
    await importCryptocurrencis();
    await updateFeeds();
  }

  Future<void> updateFeeds() async {
    if (!hasNetwork) {
      return;
    }
    for (final endpoint in rssList) {
      var rawFeed = await DataFetcher.fetchUrlData(endpoint);
      var feed = RssFeed.parse(rawFeed);
      feedList.add(feed);
    }
  }

  Future<void> updateCryptocurrencies() async {
    if (!hasNetwork) {
      return;
    }
    cryptoList = await provider.getCryptocurrencies();

    Database.updateCryptocurrencies(cryptoList);
  }

  Future<void> importCryptocurrencis() async {
    cryptoList = await Database.loadCryptocurrencies();

    if (cryptoList.isEmpty) {
      await updateCryptocurrencies();
    }
  }
}
