import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import '../models/cryptocurrency.dart';
import '../services/data_fetcher.dart';

class ChartFetcher {
  static Future<List<charts.Series<CryptoPrice, DateTime>>> fetchChartData(
      List<Cryptocurrency> cryptocurrencies, String daysToFetch) async {
    //TODO change currency too - vs_currency=usd
    final List<charts.Series<CryptoPrice, DateTime>> allChartData = [];

    int id = 0;

    for (var cryptocurrency in cryptocurrencies) {
      var rawData = await DataFetcher.fetchUrlData(
          "https://api.coingecko.com/api/v3/coins/${cryptocurrency.id}/market_chart?vs_currency=usd&days=$daysToFetch&interval=daily");

      var data = jsonDecode(rawData);

      List<CryptoPrice> singleChartData = [];

      for (var element in data["prices"]) {
        var rawDateTime = DateTime.fromMillisecondsSinceEpoch(element[0]);
        var cryptoDate =
            DateTime(rawDateTime.year, rawDateTime.month, rawDateTime.day);
        var cryptoPrice = element[1];

        singleChartData.add(CryptoPrice(cryptoDate, cryptoPrice));
      }

      charts.Color color = chartColorFromId(id++);

      allChartData.add(charts.Series<CryptoPrice, DateTime>(
        id: cryptocurrency.id,
        colorFn: (_, __) => color,
        domainFn: (CryptoPrice priceOverTime, _) => priceOverTime.time,
        measureFn: (CryptoPrice priceOverTime, _) => priceOverTime.price,
        data: singleChartData,
      ));
    }

    return allChartData;
  }

  static charts.Color chartColorFromId(int id) {
    if (id == 0) {
      return charts.MaterialPalette.blue.shadeDefault;
    } else if (id == 1) {
      return charts.MaterialPalette.red.shadeDefault;
    } else if (id == 2) {
      return charts.MaterialPalette.green.shadeDefault;
    } else if (id == 3) {
      return charts.MaterialPalette.purple.shadeDefault;
    } else if (id == 4) {
      return charts.MaterialPalette.yellow.shadeDefault;
    }

    throw Exception("Invalid id");
  }

  static MaterialColor cryptoColorFromId(int id) {
    if (id == 0) {
      return Colors.blue;
    } else if (id == 1) {
      return Colors.red;
    } else if (id == 2) {
      return Colors.green;
    } else if (id == 3) {
      return Colors.purple;
    } else if (id == 4) {
      return Colors.yellow;
    }

    throw Exception("Invalid id");
  }
}

class CryptoPrice {
  final DateTime time;
  final num price;

  CryptoPrice(this.time, this.price);
}
