import 'package:flutter/material.dart';
import '../models/cryptocurrency.dart';

class Coin extends StatelessWidget {
  final bool addCoin;
  final Cryptocurrency coin;
  final Function onClick;

  Coin(this.addCoin, this.coin, this.onClick);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Card(
        elevation: 2,
        shadowColor: Colors.black,
        shape:
            RoundedRectangleBorder(borderRadius: BorderRadius.circular(10.0)),
        margin: EdgeInsets.only(bottom: 30.0, left: 20.0, right: 20.0),
        color: Colors.white,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Row(
              children: [
                Container(
                    alignment: Alignment.topLeft,
                    margin: EdgeInsets.only(
                        top: 20.0, left: 20.0, bottom: 15.0, right: 10.0),
                    child: Image.network(coin.image, height: 75, width: 75)),
                Expanded(
                    child: Container(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      Text(
                        coin.name,
                        textAlign: TextAlign.center,
                        style: new TextStyle(
                            fontSize: 25.0, fontWeight: FontWeight.bold),
                      ),
                      Text(
                        "Price: " +
                            coin.currentPrice.toStringAsFixed(2) +
                            Cryptocurrency.currencySymbol,
                        style: new TextStyle(fontSize: 15.0),
                      )
                    ],
                  ),
                )),
              ],
            ),
            Row(
              children: [
                Container(
                    margin: EdgeInsets.only(left: 20.0, bottom: 10.0),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text("Volume: " + coin.totalVolume.toString(),
                            style: new TextStyle(fontSize: 15.0)),
                        SizedBox(height: 5),
                        Text("Marker cap: " + coin.marketCap.toString(),
                            style: new TextStyle(fontSize: 15.0))
                      ],
                    )),
                Spacer(),
                Container(
                  margin: EdgeInsets.only(right: 10.0),
                  child: addCoin == true
                      ? ElevatedButton(
                          onPressed: () {
                            onClick();
                          },
                          child: Text('Add'),
                        )
                      : ElevatedButton(
                          onPressed: () {
                            onClick();
                          },
                          child: Text("Remove"),
                        ),
                )
              ],
            ),
            ExpansionTile(
                title: Text('View more info', style: TextStyle(fontSize: 17.0)),
                children: [
                  Row(children: [
                    Expanded(
                        child: Container(
                            margin: EdgeInsets.only(left: 20.0, bottom: 10.0),
                            child: (Column(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: [
                                Text('Symbol: \n',
                                    style: TextStyle(fontSize: 15.0)),
                                Text(coin.symbol.toUpperCase(),
                                    style: TextStyle(
                                        fontWeight: FontWeight.bold,
                                        fontSize: 15.0)),
                                Text(
                                    '\nMarket cap rank: \n\n' +
                                        coin.marketCapRank.toString(),
                                    style: TextStyle(fontSize: 15.0)),
                              ],
                            )))),
                    Expanded(
                        child: Container(
                            margin: EdgeInsets.only(right: 5.0, bottom: 10.0),
                            child: (Column(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: [
                                Text('Change(1 Day): \n ',
                                    style: TextStyle(fontSize: 15.0)),
                                if (coin.priceChange24h > 0)
                                  Text(coin.priceChange24h.toString(),
                                      style: TextStyle(
                                          color: Colors.green, fontSize: 15.0))
                                else
                                  Text(coin.priceChange24h.toString(),
                                      style: TextStyle(
                                          color: Colors.red, fontSize: 15.0)),
                                Text(
                                    '\nSupply:\n\n' +
                                        coin.totalSupply.toString(),
                                    style: TextStyle(fontSize: 15.0))
                              ],
                            ))))
                  ]),
                ]),
          ],
        ),
      ),
    );
  }
}
