import 'package:flutter/material.dart';
import 'package:url_launcher/url_launcher.dart';

class News extends StatelessWidget {
  final String title;
  final String author;
  final String content;
  final String url;

  const News(this.title, this.author, this.content, this.url);

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Card(
        elevation: 2.0,
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(10.0),
        ),
        child: Column(
          children: [
            ListTile(
              leading: Icon(Icons.library_books_outlined,
                  size: 40.0, color: Colors.grey),
              title: Text(title),
              subtitle: Text(author),
            ),
            Divider(
              color: Colors.black12,
              height: 10,
              thickness: 1,
              indent: 10,
              endIndent: 10,
            ),
            ConstrainedBox(
              constraints: BoxConstraints(maxWidth: 350),
              child: Container(
                child: Text(
                  content,
                  maxLines: 5,
                  overflow: TextOverflow.ellipsis,
                ),
              ),
            ),
            ButtonBar(
              children: [
                const SizedBox(height: 30),
                ElevatedButton(
                  onPressed: () async {
                    if (await canLaunch(url)) {
                      await launch(url);
                    } else {
                      throw "Could not launch $url";
                    }
                  },
                  child: const Text('View full story'),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}
